=======
saractl
=======

`saractl` is the userspace counterpart of the S.A.R.A. LSM.
You can find more information about S.A.R.A. at <https://smeso.it/sara>.

Licensing
=========
`saractl` is released under `GPLv3 <https://www.gnu.org/licenses/gpl-3.0.html>`_ or later.

Issues
======
For any problem please open an issue `here <https://github.com/smeso/saractl/issues>`_
